#!/bin/sh
# $Id $
# Copyright (c) 2016 Joerg Jung <mail@umaxx.net>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

readonly D_V="0.1" D_YR="2016"

d_net() {
    local net=$(netstat -b -n -c2 -w1 -h -I "${1}" | tail -1) in out
    in=$(printf "$net\n" | awk '{ printf $1 }')
    out=$(printf "$net\n" | awk '{ printf $2 }')
    printf "Up: ${out} Down: ${in}"
}

d_bat() {
    local est=$(apm -m) p=$(apm -l) s
    s=$([ $(apm -a) -eq 1 ] && printf "A/C" ||
                               printf "%u:%02u" $((est/60)) $((est%60)))
    printf "Bat: $s (${p}%%)"
}

d_perf() {
    local p=$(sysctl -n hw.setperf) s=$(sysctl -n hw.cpuspeed)
    printf "Perf: %.01fGHz (${p}%%)" $(bc -l -e "${s}/1000" -e quit)
}

d_temp() {
    local t=$(sysctl -n hw.sensors | fgrep degC |
              awk '{ if ($1 > m) { m = $1 } } END { printf("%s", m) }')
    printf "Temp: ${t}degC"
}

d_vol() {
    local v=$(mixerctl -n outputs.master | cut -f1 -d',')
    printf "Vol: $(((v*100)/255))%%"
}

d_run() {
    local net b p t v
    while true; do
        net=$(d_net "${1}") b=$(d_bat) p=$(d_perf) t=$(d_temp) v=$(d_vol)
        xsetroot -name "$net $b $p $t $v $(date +'%a %R %Z %v')"
    done
}

d_main() {
    [ $# -eq 1 -a "${1}" == "version" ] &&
        { printf "dstat ${D_V} (c) ${D_YR} Joerg Jung\n"; exit 0; }
    [ $# -ne 1 ] &&
        { printf "Usage: $0 <if>\n%7s$0 version\n"; exit 1; }
    renice -n 10 $$ > /dev/null
    d_run "${1}"
}

d_main "$@"
